==> pata-password-cracker-1.0.1.tar.gz: pata-password-cracker-1.0.1/src/pata_password_cracker/gen_logo.py <==


class Logo():

    def generate_logo(self):

        print " __________         __                                        "
        print " \______   \_____ _/  |______                                 "
        print "  |     ___/\__  \\   __\__  \                                "
        print "  |    |     / __ \|  |  / __ \_                              "
        print "  |____|    (____  /__| (____  /                              "
        print "                 \/          \/                               "
        print " __________                                               .___"
        print " \______   \_____    ______ ________  _  _____________  __| _/"
        print "  |     ___/\__  \  /  ___//  ___/\ \/ \/ /  _ \_  __ \/ __ | "
        print "  |    |     / __ \_\___ \ \___ \  \     (  <_> )  | \/ /_/ | "
        print "  |____|    (____  /____  >____  >  \/\_/ \____/|__|  \____ | "
        print "                 \/     \/     \/                          \/ "
        print " _________                       __                           "
        print " \_   ___ \____________    ____ |  | __ ___________           "
        print " /    \  \/\_  __ \__  \ _/ ___\|  |/ // __ \_  __ \          "
        print " \     \____|  | \// __ \\  \___|    <\  ___/|  | \/          "
        print "  \______  /|__|  (____  /\___  >__|_ \\___  >__|             "
        print "         \/            \/     \/     \/    \/                 "
        print "                                                              "
        print "                                                              "
        print " 'Pataphysics is the science of that which is superinduced    "
        print " upon metaphysics, whether within or beyond the latter's      "
        print " limitations, extending as far beyond metaphysics as the      "
        print " latter extends beyond physics                                "
        print " - A. Jarry                                                   "
        print "                                                              "
        print " Brought to you by rpiguy......                               "
        print "                                                              "
        print "                                                              "
        print "                                                              "

==> pata-password-cracker-1.1.0.tar.gz: pata-password-cracker-1.1.0/src/pata_password_cracker/gen_logo.py <==


class Logo():

    def generate_logo(self):

        print " __________         __                                        "
        print " \______   \_____ _/  |______                                 "
        print "  |     ___/\__  \\   __\__  \                                "
        print "  |    |     / __ \|  |  / __ \_                              "
        print "  |____|    (____  /__| (____  /                              "
        print "                 \/          \/                               "
        print " __________                                               .___"
        print " \______   \_____    ______ ________  _  _____________  __| _/"
        print "  |     ___/\__  \  /  ___//  ___/\ \/ \/ /  _ \_  __ \/ __ | "
        print "  |    |     / __ \_\___ \ \___ \  \     (  <_> )  | \/ /_/ | "
        print "  |____|    (____  /____  >____  >  \/\_/ \____/|__|  \____ | "
        print "                 \/     \/     \/                          \/ "
        print " _________                       __                           "
        print " \_   ___ \____________    ____ |  | __ ___________           "
        print " /    \  \/\_  __ \__  \ _/ ___\|  |/ // __ \_  __ \          "
        print " \     \____|  | \// __ \\  \___|    <\  ___/|  | \/          "
        print "  \______  /|__|  (____  /\___  >__|_ \\___  >__|             "
        print "         \/            \/     \/     \/    \/                 "
        print "                                                              "
        print "                                                              "
        print " 'Pataphysics is the science of that which is superinduced    "
        print " upon metaphysics, whether within or beyond the latter's      "
        print " limitations, extending as far beyond metaphysics as the      "
        print " latter extends beyond physics                                "
        print " - A. Jarry                                                   "
        print "                                                              "
        print " Brought to you by patamechanix......                         "
        print "                                                              "
        print "                                                              "
        print "                                                              "
